Simulate snow mass accumulation and melt based on Orth et al. (2013) https://www.jstor.org/stable/24914341
simulate_snow(df, varnam_temp, varnam_prec, varnam_snow)A data frame containing columns for air temperature (deg. C), precipitation in liquid form (rain, mm d-1), and precipitation in solid form (snow water equivalents, mm d-1). The column names of the respective variables are provided by the other arguments. Data frame must contain at least 365 days (i.e. a full year). It can, however, contain more e.g. 400 days, i.e. the current year still ongoing.
A character string specifying the variable name for air temperature.
A character string specifying the variable name for rain.
A character string specifying the variable name for snow.
Returns a data frame with two added columns: (1) liquid_to_soil
is the rain plus snow melt in mm d-1; (2) snow_pool is the snow mass
in water equivalents (mm) for each day.